@@ -126,7 +126,12 @@ class MyStackedWidget(QtWidgets.QStackedWidget):
             
             self.setCurrentIndex(0)
             #self.pollingTimer.start()
-            device = getDevice(self.slot_no)
+            while True:
+                ready, device = getDevice(self.slot_no)
+                if ready:
+                    break
+                time.sleep(0.2)
+            print('slot_',self.slot_no,'device ready')
             self.cassettePolling=CassettePolling(self.slot_no, device[0], device[1], queueForResult, queueForCom, self.pollingCallback)
             self.cassettePolling.start()
             
